@@ -1,29 +1,19 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                       David Faure <faure@kde.org>
-    Copyright (C) 2006 Kevin Ottens <ervin@kde.org>
+/*
+    This file is part of the KDE libraries
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2006 Kevin Ottens <ervin@kde.org>
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KJOBUIDELEGATE_H
 #define KJOBUIDELEGATE_H
 
+#include <QObject>
 #include <kcoreaddons_export.h>
-#include <QtCore/QObject>
+#include <memory>
 
 class KJob;
 
@@ -44,9 +34,27 @@ class KCOREADDONS_EXPORT KJobUiDelegate : public QObject
 
 public:
     /**
-     * Constructs a new KJobUiDelegate.
+     * Flags for the constructor, to enable automatic handling of errors and/or warnings
+     * @see Flags
+     * @since 5.70
      */
-    KJobUiDelegate();
+    enum Flag {
+        AutoHandlingDisabled = 0, ///< No automatic handling (default)
+        AutoErrorHandlingEnabled = 1, ///< Equivalent to setAutoErrorHandlingEnabled(true)
+        AutoWarningHandlingEnabled = 2, ///< Equivalent to setAutoWarningHandlingEnabled(true)
+        AutoHandlingEnabled = AutoErrorHandlingEnabled | AutoWarningHandlingEnabled, ///< Enables both error and warning handling
+    };
+    /**
+     * Stores a combination of #Flag values.
+     */
+    Q_DECLARE_FLAGS(Flags, Flag)
+
+    /**
+     * Constructs a new KJobUiDelegate with a flags argument.
+     * @param flags allows to enable automatic error/warning handling
+     * @since 5.70
+     */
+    explicit KJobUiDelegate(Flags flags = {KJobUiDelegate::AutoHandlingDisabled});
 
     /**
      * Destroys a KJobUiDelegate.
@@ -57,7 +65,10 @@ protected:
     /**
      * Attach this UI delegate to a job. Once attached it'll track the job events.
      *
-     * @return true if the job we're correctly attached to the job, false otherwise.
+     * @return @c true if this UI delegate was successfully attached to @p job, @c false otherwise
+     *
+     * @note if this UI delegate is already attached to a job, calling this method will return
+     * @c false.
      */
     virtual bool setJob(KJob *job);
 
@@ -65,7 +76,7 @@ protected:
     /**
      * Retrieves the current job this UI delegate is attached to.
      *
-     * @return current job this UI delegate is attached to, or 0 if
+     * @return current job this UI delegate is attached to, or @c nullptr if
      * this UI delegate is not tracking any job
      */
     KJob *job() const;
@@ -74,10 +85,13 @@ protected:
 
 public:
     /**
-     * Display a dialog box to inform the user of the error given by
-     * this job.
-     * Only call if error is not 0, and only in the slot connected
-     * to result.
+     * Display to the user the error given by this job.
+     * The default implementation uses qWarning(). Subclasses
+     * reimplement this to use something more user-visible such
+     * as a message box.
+     *
+     * Only call this method if error is not 0, and only in the
+     * slot connected to result.
      */
     virtual void showErrorMessage();
 
@@ -126,15 +140,15 @@ public:
     bool isAutoWarningHandlingEnabled() const;
 
 protected Q_SLOTS:
-    virtual void slotWarning(KJob *job, const QString &plain, const QString &rich);
+    virtual void slotWarning(KJob *job, const QString &message);
 
 private:
-    void connectJob(KJob *job);
+    KCOREADDONS_NO_EXPORT void connectJob(KJob *job);
 
-    Q_PRIVATE_SLOT(d, void _k_result(KJob *))
-
-    class Private;
-    Private *const d;
+private:
+    std::unique_ptr<class KJobUiDelegatePrivate> const d;
 };
 
+Q_DECLARE_OPERATORS_FOR_FLAGS(KJobUiDelegate::Flags)
+
 #endif // KJOBUIDELEGATE_H
